<?php
/**
 * Elementor Widget
 * @package Smartwp
 * @since 1.0.0
 */

namespace Elementor;
class smartwp_service extends Widget_Base {

	/**
	 * Get widget name.
	 *
	 * Retrieve Elementor widget name.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget name.
	 */
	public function get_name() {
		return 'smartwp-service';
	}

	/**
	 * Get widget title.
	 *
	 * Retrieve Elementor widget title.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget title.
	 */
	public function get_title() {
		return esc_html__( 'Service', 'smartwp' );
	}

	/**
	 * Get widget icon.
	 *
	 * Retrieve Elementor widget icon.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return string Widget icon.
	 */
	public function get_icon() {
		return 'eicon-product-info';
	}

	/**
	 * Get widget categories.
	 *
	 * Retrieve the list of categories the Elementor widget belongs to.
	 *
	 * @since 1.0.0
	 * @access public
	 *
	 * @return array Widget categories.
	 */
	public function get_categories() {
		return [ 'smartwp_widgets' ];
	}

	/**
	 * Register Elementor widget controls.
	 *
	 * Adds different input fields to allow the user to change and customize the widget settings.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function _register_controls() {

		$this->start_controls_section(
			'settings_section',
			[
				'label' => esc_html__( 'General Settings', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control(
			'title',
			[
				'label'       => esc_html__( 'Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'enter title text.', 'smartwp' ),
				'default'	  => esc_html__( 'Exclusive Services', 'smartwp' )
			]
		);		

		$this->add_control(
			'sub-title',
			[
				'label'       => esc_html__( 'Sub Title', 'smartwp' ),
				'type'        => Controls_Manager::TEXTAREA,
				'description' => esc_html__( 'From banking and insurance to wealth management and on securities distrib ution.', 'smartwp' ),
			]
		);

		$this->end_controls_section();
		

		$this->start_controls_section(
			'service_section',
			[
				'label' => esc_html__( 'Service Item', 'smartwp' ),
				'tab'   => Controls_Manager::TAB_CONTENT,
			]
		);

		$this->add_control( 'service_items', [
			'label'       => esc_html__( 'Service Item', 'smartwp' ),
			'type'        => Controls_Manager::REPEATER,
			'default'     => [
				[
					'title' => esc_html__( 'Global coverage', 'smartwp' ),
					'btnText' => esc_html__( 'Learn More', 'smartwp' ),
				]
			],
			'fields'      => [

				[
					'name'        => 'title',
					'label'       => esc_html__( 'Service Name', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
					'description' => esc_html__( 'Service Name', 'smartwp' )
				],
				[
					'name'        => 'content',
					'label'       => esc_html__( 'content', 'smartwp' ),
					'type'        => Controls_Manager::TEXTAREA,
				],
				[
					'name'        => 'image',
					'label'       => esc_html__( 'Service Icon Image', 'smartwp' ),
					'type'        => Controls_Manager::MEDIA,
					'default'     =>
						array(
							'url' => Utils::get_placeholder_image_src(),
						),
					'description' => esc_html__( 'upload Icon Image', 'smartwp' )
				],
				[
					'name'        => 'btnText',
					'label'       => esc_html__( 'Button Text', 'smartwp' ),
					'type'        => Controls_Manager::TEXT,
				],				
				[
					'name'        => 'btnUrl',
					'label'       => esc_html__( 'Button Url', 'smartwp' ),
					'type'        => Controls_Manager::URL,
					'default'	  =>array(
						'url'=>'#'
					)
				],	

			],
			'title_field' => "{{name}}"
		] );


		$this->end_controls_section();

	}

	/**
	 * Render Elementor widget output on the frontend.
	 *
	 * Written in PHP and used to generate the final HTML.
	 *
	 * @since 1.0.0
	 * @access protected
	 */
	protected function render() {
		$settings = $this->get_settings_for_display();
		$service_items = $settings['service_items'];

		?>	
		<!-- Exclusive Services Start -->
			<section class="exclusive-services theme-bg p-tb-120" id="services">
				<div class="container">
					<!-- Section Title -->
					<div class="section-title m-b-60 text-center">
						<h3><?php echo esc_html( $settings['title'] ); ?></h3>
						<p><?php echo esc_html( $settings[ 'sub-title' ] ); ?></p>
					</div>

					<!-- Services box -->
					<div class="row">
						<?php foreach( $service_items as $item ) : ?>
							<div class="col-lg-4 col-md-6 col-12">
								<!-- Single feature box -->
			    				<div class="single-exclusive-box trans-03 p-all-38">
			    					<div class="exclusive-img trans-03 m-b-30">
			    						<img src="<?php echo esc_url( $item['image']['url'] ); ?>" alt="Image">
			    					</div>
			    					<div class="exclusive-content">
			    						<h4 class="fs-22 m-b-25 trans-03"><?php echo esc_html( $item['title'] ); ?></h4>
										<p><?php echo esc_html( $item['content'] ); ?></p>
										<a href="<?php echo esc_url( $item['btnUrl']['url'] ); ?>" class="learn-more"><?php echo esc_html( $item['btnText'] ); ?></a>
			    					</div>
			    				</div>
			    			</div>
		    			<?php endforeach; ?>
					</div>
				</div>
			</section>
		<!-- Pricing Section Start -->

		<?php
	}
}

Plugin::instance()->widgets_manager->register_widget_type( new smartwp_service() );